<?php

/**
 * @file
 * Admin page callbacks for the freecommerce module.
 */

/**
 * Form constructor for the freecommerce admin settings.
 *
 * @see freecommerce_max_order_validate()
 *
 * @ingroup forms
 */
function freecommerce_admin_settings() {
  $form['orderform'] = array(
    '#type' => 'fieldset',
    '#title' => t('Order Form'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['orderform']['freecommerce_address_fields'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Order form fields'),
    '#default_value' => variable_get('freecommerce_address_fields', array('first_name', 'last_name', 'address1', 'city', 'state', 'zip', 'country', 'email')),
    '#options' => freecommerce_grab_address_fields(),
  );

  $form['orderform']['freecommerce_email_autopopulate'] = array(
    '#type' => 'checkbox',
    '#title' => t('Auto-populate email field?'),
    '#description' => t('Auto-populate email field with current user\'s email'),
    '#default_value' => 1,
  );

  $form['content_types'] = array(
    '#type' => 'fieldset',
    '#title' => t('Content types'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $nodes = array();
  $types = node_type_get_types();
  foreach ($types as $type) {
    $nodes[$type->name] = $type->name;
  }

  $form['content_types']['freecommerce_nodes'] = array(
    '#type' => 'checkboxes',
    '#title' => t('The following nodes can be ordered via Freecommerce'),
    '#default_value' => array_filter(variable_get('freecommerce_nodes', array())),
    '#options' => $nodes,
    '#description' => t('Select content types to categorize using this vocabulary.'),
  );

  $form['content_types']['freecommerce_max_order'] = array(
    '#type' => 'textfield',
    '#title' => t('Max. items'),
    '#default_value' => variable_get('freecommerce_max_order', 10),
    '#size' => 3,
    '#maxlength' => 3,
    '#description' => t('The maximum number of items per node per order.'),
  );

  $form['contacts'] = array(
    '#type' => 'fieldset',
    '#title' => t('Contacts'),
    '#collapsible' => TRUE,
    '#collapsed' => FALSE,
  );

  $form['contacts']['freecommerce_contacts_misc'] = array(
    '#type' => 'textarea',
    '#title' => t('E-mail the following'),
    '#default_value' => variable_get('freecommerce_contacts_misc', ''),
    '#description' => t('Info on every order will be sent to these e-mail addresses (if valid). One address per line.'),
  );

  $form['#validate'][] = 'freecommerce_max_order_validate';

  return system_settings_form($form);
}

/**
 * Form validation handler for freecommerce_admin_settings().
 */
function freecommerce_max_order_validate($form, &$form_state) {
  $v = (int)$form_state['values']['freecommerce_max_order'];
  if ($v < 1 || $v > 100) {
    form_error($element, t('Max order value must be an integer from 1 to 100.'));
  }
}