<?php

/**
 * @file
 * Checkout page callbacks etc. for the freecommerce module.
 */

/**
 * Form constructor for the checkout form.
 *
 * @see freecommerce_checkout_validate()
 * @see freecommerce_checkout_submit()
 *
 * @ingroup forms
 */
function freecommerce_checkout() {
  // See if user wants to Return to Cart
  if (isset($_POST['op']) && $_POST['op'] == t('Return to Cart')) {
    drupal_goto('cart');
  }

  if (isset($_SESSION['freecommerce_cart'])) {
    include 'freecommerce.cart.php';
    $table = freecommerce_product_table();
  }
  else {
    drupal_goto('cart');
  }

  drupal_add_css(drupal_get_path('module', 'freecommerce') . '/freecommerce_cart.css');

  $form['product_table'] = array(
    '#value' => $table,
  );
  $form['return_cart'] = array(
    '#type' => 'submit',
    '#value' => t('Return to Cart'),
    '#submit' => FALSE,
  );
  require 'freecommerce_fields.inc.php';
  $fields = variable_get('freecommerce_address_fields', array('email'));
  foreach ($freecommerce_fields as $name => $field) {
    if (in_array($name, $fields, TRUE)) {
      $form[$name] = $field;
      $form[$name]['#required'] = TRUE;
    }
  }

  // if user logged in and has email address
  // autopopulate email field
  global $user;
  if ($user->uid > 0  && $user->mail != '' && variable_get('freecommerce_email_autopopulate', 0)) {
    $form['email']['#default_value'] = $user->mail;
  }

  $form['submit'] = array(
    '#type' => 'submit',
    '#value' => t('Submit order'),
    '#weight' => 10,
  );

  $form['#validate'][] = 'freecommerce_checkout_validate';
  $form['#submit'][] = 'freecommerce_checkout_submit';

  return $form;
}

/**
 * Form validation handler for freecommerce_checkout().
 *
 * @see freecommerce_checkout_submit()
 */
function freecommerce_checkout_validate($form, &$form_state) {
  $email = $form_state['values']['email'];
  if ($email && !valid_email_address($email)) {
    form_set_error('email', t('Please input a valid email address.'));
  }
}

/**
 * Form submission handler for freecommerce_checkout().
 *
 * @see freecommerce_checkout_validate()
 */
function freecommerce_checkout_submit($form, &$form_state) {
  $cart = $_SESSION['freecommerce_cart'];
  if ($cart) {
    // generate customer info
    $customer_info = '';
    $info = t('CUSTOMER INFORMATION') . "\n";
    $info .= '----------------------' . "\n";
    $ok_fields = variable_get('freecommerce_address_fields', array());
    foreach ($form_state['values'] as $k => $v) {
      if (in_array($k, $ok_fields, TRUE)) {
        $customer_info .= $k . ': ' . $v . "\n";
      }
    }

    // generate standard recipient info
    $emails = array();
    $misc = variable_get('freecommerce_contacts_misc', '');

    if ($misc) {
      $emails = array_merge($emails, preg_split("/\s+/", $misc));
    }

    foreach ($cart as $id => $product) {
      $node = node_load($id);
      $to = implode(', ', $emails);

      global $language;
      drupal_mail('freecommerce', 'order', $to, $language->language, array('title' => $product['title'], 'quantity' => $product['quantity'], 'customer_info' => $customer_info));
      drupal_set_message(t('Your order has been sent.'));
    }
    unset($_SESSION['freecommerce_cart']);    
  }
  else {
    $msg = t('Nothing in cart');
  }
}

/**
 * Implements hook_mail().
 */
function freecommerce_mail($key, &$message, $params) {
  if ($key == 'order') {
    $message['subject'] = t('ORDER') . ': ' . $params['title'];
    $body =  t('ORDER INFORMATION') . "\n";
    $body .= '---------------------' . "\n";
    $body .= t('PRODUCT') . ': ' . $params['title'] . "\n";
    $body .= t('QUANTITY') . ': ' . $params['quantity'] . "\n";
    $body .= t('ORDER DATE') . ': ' . format_date(time()) . "\n";
    $body .= $params['customer_info'];
    $message['body'][] = $body;
  }
}
